@@ -318,25 +318,32 @@ class WinOSClient:
 
         Used command-line (cmd.exe, powershell or bash)
 
+        Add mandatory param "CMD" or "PS" to use appropriate transport
+
         :param cmd: string, command
         :param timeout: timeout for command
         :return: Decoded response
         """
 
-        src = 'LOCAL'
-        self.logger.info(f'{src:<14} | {cmd}')
+        self.logger.info(cmd)
 
-        response = subprocess.run(['powershell', '-Command', cmd], capture_output=True, timeout=timeout)
+        response = subprocess.run(cmd, capture_output=True, timeout=timeout)
         parsed = WinResponse(response, command=cmd)
 
-        # Log response
-        msg_to_log = f'{parsed.exited}:\n\t{parsed.stdout}' if parsed.stdout else f'{parsed.exited}:'
-        self.logger.info(f'{src:<14} | {msg_to_log}')
-        self.logger.debug(f'{src:<14} | \n{parsed.to_debug_log}')
+        # Log ERROR
+        msg_err = f'Something went wrong!\n\t{parsed.exited}: {parsed.stderr}'
+        if parsed.exited:  # Exit code != 0 or stderr contains text
+            self.logger.error(msg_err)
+            raise RemoteCommandExecutionError(parsed.stderr)
 
-        if parsed.stderr:
-            self.logger.error(f'{src:<14} | \n{parsed.stderr}')
-            raise LocalCommandExecutionError(parsed.stderr)
+        # Log WARNING
+        if parsed.stderr:  # warning detected
+            self.logger.warning(msg_err)
+
+        # Log INFO and DEBUG
+        msg_to_log = f'{parsed.exited}:\n\t{parsed.stdout}' if parsed.stdout else f'{parsed.exited}:'
+        self.logger.info(msg_to_log)
+        self.logger.debug(f'\n{parsed.to_debug_log}')
 
         return parsed
 
@@ -396,12 +403,12 @@ class WinOSClient:
         return self._run_local(command, timeout)
 
     def run_ps_local(self, command: str = None, script: str = None, timeout: int = 60, **params):
-        cmd = f"powershell -command \"{command}\""
+        cmd = f'powershell -command "{command}"'
         if script:
             params_ = ' '.join([f'-{key} {value}' for key, value in params.items()])
             cmd = f'powershell -file {script} {params_}'
 
-        return self._run_local(cmd, timeout=timeout)
+        return self._run_local(cmd, timeout)
 
     # ----------------- High-level methods ----------------
     def remove_item(self, path: str, ignore_errors: bool = False) -> bool:
@@ -433,17 +440,6 @@ class WinOSClient:
 
         return self.get_os_info().get('Caption')
 
-    def ping(self, host: str = '', packets_number: int = 4):
-        """Ping remote host from current one.
-
-        :param host: IP address to ping. Used host IP from init by default
-        :param packets_number: Number of packets. 4 by default
-        """
-
-        ip_ = host if host else self.host
-        command = f'ping -n {packets_number} {ip_}'
-        return self._run_local(cmd=command)
-
     def exists(self, path: str) -> bool:
         """Check file/directory exists from remote server
 
@@ -597,7 +593,7 @@ class WinOSClient:
 
         return result.stdout
 
-    @staticmethod  # TODO V2V
+    @staticmethod
     def get_hash_local(path: str, algorithm: str = 'MD5') -> str:
         """Open file and calculate hash
 
